#include "foo.h"
#include "basic.h"
int main() {
  basic();
  foo();
  return 0;
}
